@@ -1,78 +1,82 @@
 package Form::Processor::Field;
+{
+  $Form::Processor::Field::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Rose::Object';
-use Form::Processor::I18N;  # only needed if running without a form object.
+use Form::Processor::I18N;    # only needed if running without a form object.
 use Scalar::Util;
 
 
-our $VERSION = '0.03';
+
 
 
 use Rose::Object::MakeMethods::Generic (
     scalar => [
-        'name',         # Field's name
-        'init_value',   # initial value populated by init_from_object - used to look for changes
-                        # not to be confused with the form method init_value().
-        'value',        # scalar internal value -- same as init_value at start.
-        'input',        # input value from parameter
-        'temp',         # Temporary storage for fields to save validated data - DEPRECATED -- not really needed.
-        'type',         # field type (e.g. 'Text', 'Select' ... )
-        'label',        # Text label -- not really used much, yet.
-        'style',        # Field's generic style to use for css formatting
-        #'form',         # The parent form (defined below)
-        'sub_form',     # The field is made up of a sub-form.
-        # This is a more generic field type that can be used
-        # in template to determine what type of html widget to generate
-        widget      =>  { interface => 'get_set_init' },
-        order       =>  { interface => 'get_set_init' },
+        'name',               # Field's name
+        'init_value',         # initial value populated by init_from_object - used to look for changes
+                              # not to be confused with the form method init_value().
+        'value',              # scalar internal value -- same as init_value at start.
+        'input',              # input value from parameter
+        'temp',               # Temporary storage for fields to save validated data - DEPRECATED -- not really needed.
+        'type',               # field type (e.g. 'Text', 'Select' ... )
+        'label',              # Text label -- not really used much, yet.
+        'style',              # Field's generic style to use for css formatting
+                              #'form',         # The parent form (defined below)
+        'sub_form',           # The field is made up of a sub-form.
+                              # This is a more generic field type that can be used
+                              # in template to determine what type of html widget to generate
+        widget           => { interface => 'get_set_init' },
+        order            => { interface => 'get_set_init' },
         required_message => { interface => 'get_set_init' },
 
         # Allow ragne checks -- done after validation so
         # must only be used on appropriate fields
         # These really should be defined in a subclass that only deals
         # with numbers.
-        range_start  => { interface => 'get_set_init' },
-        range_end    => { interface => 'get_set_init' },
+        range_start => { interface => 'get_set_init' },
+        range_end   => { interface => 'get_set_init' },
 
-        value_format => { interface => 'get_set_init' },  # sprintf format to use when converting input to value
+        value_format => { interface => 'get_set_init' },    # sprintf format to use when converting input to value
 
         # Often the fields need a unique id for js, so many a
         # handy way to get this.
-        id           => { interface => 'get_set_init' },
+        id => { interface => 'get_set_init' },
 
-        max_size     => { interface => 'get_set_init' },
+        max_size => { interface => 'get_set_init' },
 
     ],
 
     boolean => [
+
         # These should probably be 'get_set' here and then 'get_set_init' any
         # place that needs to define an initial value.
-        password    => { interface => 'get_set_init' },  # don't return field in $form->fif
-        required    => { interface => 'get_set_init' },  # field is requried
-        writeonly   => { interface => 'get_set_init' },  # don't call format_value on this field
-        clear       => { interface => 'get_set_init' },  # don't validate and remove from database
+        password  => { interface => 'get_set_init' },    # don't return field in $form->fif
+        required  => { interface => 'get_set_init' },    # field is requried
+        writeonly => { interface => 'get_set_init' },    # don't call format_value on this field
+        clear     => { interface => 'get_set_init' },    # don't validate and remove from database
 
         # disabled and readonly mirror the html form specification
         # disabled fields are not suppose to be "successful" and thus
         # should not be updated.  But.. see "noupdate" below.
-        disabled    => { interface => 'get_set_init' }.     # Don't update this field in the database.
+        disabled => { interface => 'get_set_init' } .    # Don't update this field in the database.
 
-        # readonly fields are basically like hidden fields that the UI
-        # should no be able to modify but still are submitted.
-        readonly    => { interface => 'get_set_init' },     # Flag to indicate readonly field
+            # readonly fields are basically like hidden fields that the UI
+            # should no be able to modify but still are submitted.
+            readonly => { interface => 'get_set_init' },    # Flag to indicate readonly field
 
         # Since disabled and readonly effect the UI differently
         # use a separate flag to tell the model to not update a field.
-        noupdate    => { interface => 'get_set_init' },    # don't update this field in the database
+        noupdate => { interface => 'get_set_init' },        # don't update this field in the database
 
-        must_submit => { interface => 'get_set' }       # override use_existing_values
+        must_submit => { interface => 'get_set' }           # override use_existing_values
     ],
 
     array => [
-        errors          => {},
-        reset_errors    => { interface => 'reset', hash_key => 'errors' },
-        add_error_str   => { interface => 'push',  hash_key => 'errors' },
+        errors        => {},
+        reset_errors  => { interface => 'reset', hash_key => 'errors' },
+        add_error_str => { interface => 'push', hash_key => 'errors' },
     ],
 );
 
@@ -80,17 +84,386 @@ use Rose::Object::MakeMethods::Generic (
 ## Should $value be overridden to only return a value if there are not
 #  any errors?
 
+# ABSTRACT: Base class for Fields used with Form::Processor
+
+
+
+sub init {
+    my $self = shift;
+
+    $self->SUPER::init( @_ );
+
+    die "Need to supply name parameter"
+        unless $self->name;
+}
+
+
+sub full_name {
+    my $field = shift;
+
+    my $name   = $field->name;
+    my $form   = $field->form || return $name;
+    my $parent = $form->parent_field || return $name;
+    return $parent->name . '.' . $name;
+}
+
+
+sub form {
+    my $self = shift;
+    return Scalar::Util::weaken( $self->{form} = shift ) if ( @_ );
+    return $self->{form};
+}
+
+
+sub init_id {
+    my $field = shift;
+    my $form_name = $field->form ? $field->form->name : 'fld-';
+    return $field->form->name . $field->name
+}
+
+
+sub init_widget {'text'}
+
+
+sub init_order {1}
+
+
+sub set_order {
+    my $field = shift;
+    my $form  = $field->form;
+    my $order = $form->field_counter || 1;
+    $field->order( $order );
+    $form->field_counter( $order + 1 );
+}
+
+
+sub init_required {0}
+
+
+sub add_error {
+    my $self = shift;
+
+    my $form = $self->form;
+
+    my $lh;
+
+    # By default errors get attached to the field where they happen.
+    my $error_field = $self;
+
+    # Running without a form object?
+    if ( $form ) {
+        $lh = $form->language_handle;
+
+        # If we are a sub-form then redirect errors to the parent field
+        $error_field = $form->parent_field if $form->parent_field;
+    }
+    else {
+        $lh = $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
+            die "Failed call to Text::Maketext->get_handle";
+    }
+
+    $self->add_error_str( $lh->maketext( @_ ) );
+
+    return;
+
+}
+
+
+sub init_max_size {10_000}    # sanity check
+
+
+
+sub init_range_start {return}
+sub init_range_end   {return}
+
+
+sub validate_field {
+    my $field = shift;
+
+    $field->reset_errors;
+    $field->value( undef );
+
+
+    # See if anything was submitted
+    unless ( $field->any_input ) {
+        $field->add_error( $field->required_message )
+            if $field->required;
+
+        return !$field->required;
+    }
+
+    return unless $field->test_multiple;
+    return unless $field->test_options;
+
+
+    # Check for max length new .20.
+    if ( my $size = $field->max_size ) {
+
+        my $value = $field->input;
+
+        if ( length( $value ) > $size ) {
+            $field->add_error( 'Please limit to [quant,_1,character]. You submitted [_2]', $size, length $value );
+            return;
+        }
+    }
+
+
+    return unless $field->validate;
+    return unless $field->test_ranges;
+
+
+    # Now move data from input -> value
+    $field->input_to_value;
+
+    return $field->validate_value unless $field->has_error;
+
+    return;
+}
+
+
+sub validate {1}
+
+
+sub validate_value {1}
+
+
+sub init_value_format {return}
+
+
+sub input_to_value {
+    my $field = shift;
+
+    return if defined $field->value;    # already set by validate method.
+
+    my $format = $field->value_format;
+
+    if ( $format ) {
+        $field->value( sprintf( $format, $field->input ) );
+    }
+
+    else {
+        $field->value( $field->input );
+    }
+}
+
+
+sub test_ranges {
+    my $field = shift;
+    return 1 if $field->can( 'options' ) || $field->has_error;
+
+    my $input = $field->input;
+
+
+    return 1 unless defined $input;
+
+    my $low  = $field->range_start;
+    my $high = $field->range_end;
+
+    if ( defined $low && defined $high ) {
+        return $input >= $low && $input <= $high
+            ? 1
+            : $field->add_error( 'value must be between [_1] and [_2]', $low, $high );
+    }
+
+    if ( defined $low ) {
+        return $input >= $low
+            ? 1
+            : $field->add_error( 'value must be greater than or equal to [_1]', $low );
+    }
+
+    if ( defined $high ) {
+        return $input <= $high
+            ? 1
+            : $field->add_error( 'value must be less than or equal to [_1]', $high );
+    }
+
+    return 1;
+}
+
+
+
+
+
+sub trim_value {
+    my ( $self, $value ) = @_;
+
+    return unless defined $value;
+
+    my @values = ref $value eq 'ARRAY' ? @$value : ( $value );
+
+    for ( @values ) {
+        next if ref $_;
+        s/^\s+//;
+        s/\s+$//;
+    }
+
+    return @values > 1 ? \@values : $values[0];
+}
+
+
+sub init_required_message {'This field is required'}
+
+
+sub test_multiple {
+    my ( $self ) = @_;
+
+    my $value = $self->input;
+
+    if ( ref $value eq 'ARRAY' && !( $self->can( 'multiple' ) && $self->multiple ) ) {
+        $self->add_error( 'This field does not take multiple values' );
+        return;
+    }
+
+    return 1;
+}
+
+
+sub any_input {
+    my ( $self ) = @_;
+
+
+    my $found;
+
+    my $value = $self->input;
+
+    # check for one value as defined
+    return grep {/\S/} @$value
+        if ref $value eq 'ARRAY';
+
+    return defined $value && $value =~ /\S/;
+}
+
+
+sub test_options {
+    my ( $self ) = @_;
+
+    return 1 unless $self->can( 'options' );
+
+    # create a lookup hash
+    my %options = map { $_->{value} => 1 } $self->options;
+
+    my $input = $self->input;
+
+    return 1 unless defined $input;    # nothing to check
+
+    for my $value ( ref $input eq 'ARRAY' ? @$input : ( $input ) ) {
+        unless ( $options{$value} ) {
+            $self->add_error( "'[_1]' is not a valid value", $value );
+            return;
+        }
+    }
+
+    return 1;
+}
+
+
+
+sub format_value {
+    my $self  = shift;
+    my $value = $self->value;
+    return defined $value ? ( $self->name, $value ) : ();
+}
+
+
+sub init_noupdate {0}
+
+
+sub init_disabled {0}
+sub init_readonly {0}
+
+
+sub init_clear {0}
+
+
+sub init_writeonly {0}
+
+
+
+sub init_password {0}
+
+
+sub value_changed {
+    my ( $self ) = @_;
+
+    my @cmp;
+
+    for ( qw/ init_value value / ) {
+        my $val = $self->$_;
+        $val = '' unless defined $val;
+
+        push @cmp, join '|',
+            sort
+            map {
+            ref( $_ ) && $_->isa( 'DateTime' )
+                ? $_->iso8601
+                : "$_"
+            } ref( $val ) eq 'ARRAY' ? @$val : $val;
+
+    }
+
+    return $cmp[0] ne $cmp[1];
+}
+
+
+sub required_text { shift->required ? 'required' : 'optional' }
+
+
+sub has_error {
+    my $self   = shift;
+    my $errors = $self->errors;
+    return unless $errors;
+    return scalar @$errors;
+}
+
+
+
+
+
+sub dump {
+    my $f = shift;
+    require Data::Dumper;
+    warn "\n---------- [ ", $f->name, " ] ---------------\n";
+    warn "Field Type: ", ref( $f ), "\n";
+    warn "Required: ", ( $f->required || '0' ), "\n";
+    warn "Password: ", ( $f->password || '0' ), "\n";
+    my $v = $f->value;
+    warn "Value: ", Data::Dumper::Dumper $v;
+    my $iv = $f->init_value;
+    warn "InitValue: ", Data::Dumper::Dumper $iv;
+    my $i = $f->input;
+    warn "Input: ", Data::Dumper::Dumper $i;
+
+    if ( $f->can( 'options' ) ) {
+        my $o = $f->options;
+        warn "Options: " . Data::Dumper::Dumper $o;
+    }
+}
+
+
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field - Base class for Fields used with Form::Processor
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
     # Used from another class
     use base 'Form::Processor::Field::Text';
     my $field = Form::Processor::Field::Text->new( name => $name );
 
-
 =head1 DESCRIPTION
 
 This is a base class that allows basic functionality for form fields.
@@ -102,7 +475,6 @@ Look at the L<validate_field> method for how individual fields are validated.
 You are encouraged to create specific fields for your application instead of
 simply using the fields included with Form::Processor.
 
-
 =head1 METHODS
 
 =over 4
@@ -112,21 +484,6 @@ simply using the fields included with Form::Processor.
 Create a new instance of a field.  Any initial values may be passed in
 as a list of parameters.
 
-
-
-
-=cut
-
-
-sub init {
-    my $self = shift;
-
-    $self->SUPER::init(@_);
-
-    die "Need to supply name parameter"
-        unless $self->name;
-}
-
 =item must_submit
 
 This boolean value defaults to false.
@@ -139,7 +496,6 @@ on a per-field basis.
 
 This has no effect if "use_existing_values" is false on the form.
 
-
 =item full_name
 
 This returns the name of the field, but if the field
@@ -147,35 +503,16 @@ is a child field will prepend the field with the parent's field
 name.  For example, if a field is "month" and the parent's field name
 is "birthday" then this will return "birthday.month".
 
-=cut
-
-sub full_name {
-    my $field = shift;
-
-    my $name = $field->name;
-    my $form = $field->form || return $name;
-    my $parent = $form->parent_field || return $name;
-    return $parent->name . '.' . $name;
-}
-
 =item form
 
 This is a reference to the parent form object.
 It's stored weakened references.
 
-=cut
-
-sub form {
-    my $self = shift;
-    return Scalar::Util::weaken( $self->{form} = shift ) if( @_ );
-    return $self->{form};
-}
 =item sub_form
 
 A single field can be represented by more than one sub-fields
 contained in a form.  This is a reference to that form.
 
-
 =item id
 
 Returns an id for the field, which is by default:
@@ -184,14 +521,6 @@ Returns an id for the field, which is by default:
 
 A field may override with "init_id".
 
-=cut
-
-sub init_id {
-    my $field = shift;
-    my $form_name = $field->form ? $field->form->name : 'fld-';
-    return $field->form->name . $field->name
-}
-
 =item init_widget
 
 This is the generic type of widget that could be used
@@ -226,20 +555,10 @@ a group of checkboxes.
 
 The default type is 'text'.
 
-
-
-=cut
-
-sub init_widget { 'text' }
-
 =item order
 
 This is the field's order used for sorting errors and field lists.
 
-=cut
-
-sub init_order { 1 }
-
 =item set_order
 
 This sets the field's order to the form's field_counter
@@ -250,16 +569,6 @@ this can be called with displaying the field to set its order.
 Then a summary of error messages can be displayed in the order
 the fields are on the form.
 
-=cut
-
-sub set_order {
-    my $field = shift;
-    my $form = $field->form;
-    my $order = $form->field_counter || 1;
-    $field->order( $order );
-    $form->field_counter( $order + 1 );
-}
-
 =item value
 
 Sets or returns the internal value of the field.
@@ -270,10 +579,6 @@ The "validate" field method must set this value if the field validates.
 
 Sets or returns the required flag on the field
 
-=cut
-
-sub init_required { 0 }
-
 =item errors
 
 returns the error (or list of errors if more than one was set)
@@ -288,36 +593,6 @@ Returns undef.  This allows:
 
     return $field->add_error( 'bad data' ) if $bad;
 
-=cut
-
-sub add_error {
-    my $self = shift;
-
-    my $form = $self->form;
-
-    my $lh;
-
-    # By default errors get attached to the field where they happen.
-    my $error_field = $self;
-
-    # Running without a form object?
-    if ( $form ) {
-        $lh = $form->language_handle;
-
-        # If we are a sub-form then redirect errors to the parent field
-        $error_field = $form->parent_field if $form->parent_field;
-    }
-    else {
-        $lh = $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
-            die "Failed call to Text::Maketext->get_handle";
-    }
-
-    $self->add_error_str( $lh->maketext( @_ ) );
-
-    return;
-
-}
-
 =item max_size
 
 This can be used to specify a max length of a field.
@@ -325,17 +600,11 @@ Defaults to 10,000 characters.
 
 Added in .20 as a sanity check.
 
-=cut
-
-sub init_max_size { 10_000 } # sanity check
-
 =item min_length
 
 If set "Text"-based fields must be this many charactres long to validate.
 Default is zero.
 
-=cut
-
 =item range_start
 =item range_end
 
@@ -360,17 +629,11 @@ For example, in a profile:
 Will test that any age entered will be in the range of
 of 18 to 120, inclusive.  Open ended can be done by simply:
 
-
     age => {
         type            => 'Integer',
         range_start     => 18,
     }
 
-=cut
-
-sub init_range_start { return }
-sub init_range_end { return }
-
 =item reest_errors
 
 Resets the list of errors.  The validate method
@@ -433,52 +696,6 @@ For example, for testing a L<DateTime> object is within a given range of dates.
 
 =back
 
-
-=cut
-
-sub validate_field {
-    my $field = shift;
-
-    $field->reset_errors;
-    $field->value(undef);
-
-
-    # See if anything was submitted
-    unless ( $field->any_input ) {
-        $field->add_error( $field->required_message )
-            if $field->required;
-
-        return !$field->required;
-    }
-
-    return unless $field->test_multiple;
-    return unless $field->test_options;
-
-
-    # Check for max length new .20.
-    if ( my $size = $field->max_size  ) {
-
-        my $value = $field->input;
-
-        if ( length( $value ) > $size ) {
-            $field->add_error( 'Please limit to [quant,_1,character]. You submitted [_2]', $size, length $value );
-            return;
-        }
-    }
-
-
-    return unless $field->validate;
-    return unless $field->test_ranges;
-
-
-    # Now move data from input -> value
-    $field->input_to_value;
-
-    return $field->validate_value unless $field->has_error;
-
-    return;
-}
-
 =item validate
 
 This method validates the input data for the field and returns true if
@@ -510,11 +727,6 @@ be placed in C<< $field->value >> at that time and will not be copied by
 C<< $field->input_to_value >>, or can place the value in a temporary location
 and then the field can also override the C<input_to_value> method.
 
-
-=cut
-
-sub validate { 1 }
-
 =item validate_value
 
 This field method is called after the raw field has been validated (with the validate method)
@@ -525,10 +737,6 @@ converted into its internal form (e.g. a DateTime object).
 
 The default method is to simply return true;
 
-=cut
-
-sub validate_value { 1 }
-
 =item value_format
 
 This is a sprintf format string that is used when moving the field's
@@ -542,10 +750,6 @@ For example in a field that represents money the field could define:
 
 And then numberic data will be formatted with two decimal places.
 
-=cut
-
-sub init_value_format { return }
-
 =item input_to_value
 
 This method is called if C<< $field->validate >> returns true.
@@ -559,68 +763,12 @@ A field's validation method can populate a field's value during
 validation, or can override this method to populate the value after
 validation has run.  Overriding this method is recommended.
 
-=cut
-
-sub input_to_value {
-    my $field = shift;
-
-    return if defined $field->value;  # already set by validate method.
-
-    my $format = $field->value_format;
-
-    if ( $format ) {
-        $field->value( sprintf( $format, $field->input ) );
-    }
-
-    else {
-        $field->value( $field->input );
-    }
-}
-
 =item test_ranges
 
 If range_start and/or range_end is set AND the field
 does not have options will test that the value is within
 range.  This is called after all other validation.
 
-=cut
-
-sub test_ranges {
-    my $field = shift;
-    return 1 if $field->can('options') || $field->has_error;
-
-    my $input = $field->input;
-
-
-    return 1 unless defined $input;
-
-    my $low     = $field->range_start;
-    my $high    = $field->range_end;
-
-    if ( defined $low && defined $high ) {
-        return $input >= $low && $input <= $high
-            ? 1
-            : $field->add_error( 'value must be between [_1] and [_2]', $low, $high );
-    }
-
-    if ( defined $low ) {
-        return $input >= $low
-            ? 1
-            : $field->add_error( 'value must be greater than or equal to [_1]', $low );
-    }
-
-    if ( defined $high ) {
-        return $input <= $high
-            ? 1
-            : $field->add_error( 'value must be less than or equal to [_1]', $high );
-    }
-
-    return 1;
-}
-
-
-
-
 =item trim_value
 
 Trims leading and trailing white space for single parameters.
@@ -628,76 +776,20 @@ If the parameter is an array ref then each value is trimmed.
 
 Pass in the value to trim and returns value back
 
-=cut
-
-sub trim_value {
-    my ($self, $value ) = @_;
-
-    return unless defined $value;
-
-    my @values = ref $value eq 'ARRAY' ? @$value : ( $value );
-
-    for ( @values ) {
-        next if ref $_;
-        s/^\s+//;
-        s/\s+$//;
-    }
-
-    return @values > 1 ? \@values : $values[0];
-}
-
 =item required_message
 
 Returns text for use in "required" message.
 The default is "This field is required".
 
-=cut
-
-sub init_required_message {  'This field is required' }
-
 =item test_multiple
 
 Returns false if the field is a multiple field
 and the input for the field is a list.
 
-
-=cut
-
-sub test_multiple {
-    my ( $self ) = @_;
-
-    my $value = $self->input;
-
-    if ( ref $value eq 'ARRAY' && !( $self->can('multiple') && $self->multiple) ) {
-        $self->add_error('This field does not take multiple values');
-        return;
-    }
-
-    return 1;
-}
-
 =item any_input
 
 Returns true if $self->input contains any non-blank input.
 
-
-=cut
-
-sub any_input {
-    my ( $self ) = @_;
-
-
-    my $found;
-
-    my $value = $self->input;
-
-    # check for one value as defined
-    return grep { /\S/ } @$value
-        if ref $value eq 'ARRAY';
-
-    return defined $value && $value =~ /\S/;
-}
-
 =item test_options
 
 If the field has an "options" method then the input value (or values
@@ -705,31 +797,6 @@ if an array ref) is tested to make sure they all are valid options.
 
 Returns true or false
 
-=cut
-
-sub test_options {
-    my ( $self ) = @_;
-
-    return 1 unless $self->can('options');
-
-    # create a lookup hash
-    my %options = map { $_->{value} => 1 }  $self->options;
-
-    my $input = $self->input;
-
-    return 1 unless defined $input;  # nothing to check
-
-    for my $value ( ref $input eq 'ARRAY' ? @$input : ($input) ) {
-        unless ( $options{$value} ) {
-            $self->add_error( "'[_1]' is not a valid value", $value );
-            return;
-        }
-    }
-
-    return 1;
-}
-
-
 =item format_value
 
 This method takes $field->value and formats it into a hash
@@ -754,14 +821,6 @@ It's up to you to not use duplicate hash values.
 You might want to override test_required() if you don't use a matching field name
 (e.g. $name . 'd' instead of just $name).
 
-=cut
-
-sub format_value {
-    my $self = shift;
-    my $value = $self->value;
-    return defined $value ? ( $self->name, $value ) : ();
-}
-
 =item noupdate
 
 This boolean flag indicates a field that should not be updated.  Field's
@@ -770,10 +829,6 @@ flagged as noupdate are skipped when processing by the model.
 This is usesful when a form contains extra fields that are not directly
 written to the data store.
 
-=cut
-
-sub init_noupdate { 0 }
-
 =item disabled
 =item readonly
 
@@ -784,20 +839,11 @@ readonly fileds can be.  Instead of depending on these field attribues, an
 Form::Processor::Model classes should instead use the L<noupdate> flag
 as an indicator if the field should be ignored or not.
 
-=cut
-
-sub init_disabled { 0 }
-sub init_readonly { 0 }
-
 =item clear
 
 This is a flag that says you want to clear the database column for this
 field.  Validation is also not run on this field.
 
-=cut
-
-sub init_clear { 0 }
-
 =item writeonly
 
 Fields flagged as writeonly are not fetched from the model when $form->params
@@ -814,11 +860,6 @@ field's initial value, but not from the parameter hash passed to the form.
 Redrawn forms (after validation failures) will display the value submitted
 in the form.
 
-=cut
-
-sub init_writeonly { 0 }
-
-
 =item password
 
 This is a boolean flag and if set the $form->params method will remove that
@@ -827,10 +868,6 @@ field when calling $form->fif.
 This is different than the C<writeonly> method above in that the value is
 removed from the hash every time its fetched.
 
-=cut
-
-sub init_password { 0 }
-
 =item value_changed
 
 Returns true if the value in the item has changed from what is currently in the
@@ -838,92 +875,30 @@ field's value.
 
 This only does a string compare (arrays are sorted and joined).
 
-=cut
-
-sub value_changed {
-    my ( $self ) = @_;
-
-    my @cmp;
-
-    for ( qw/ init_value value / ) {
-        my $val = $self->$_;
-        $val = '' unless defined $val;
-
-        push @cmp, join '|', 
-            sort
-                map {
-                        ref($_) && $_->isa('DateTime') 
-                            ? $_->iso8601 
-                            : "$_"
-                } ref($val) eq 'ARRAY' ? @$val : $val;
-
-    }
-
-    return $cmp[0] ne $cmp[1];
-}
-
 =item required_text
 
 Returns "required" or "optional" based on the field's setting.
 
-=cut
-
-sub required_text { shift->required ? 'required' : 'optional' }
-
 =item has_error
 
 Returns the count of errors on the field.
 
-=cut
-
-sub has_error {
-    my $self = shift;
-    my $errors = $self->errors;
-    return unless $errors;
-    return scalar @$errors;
-}
-
-
-
-
 =item dump_field
 
 A little debugging.
 
-=cut
-
-sub dump {
-    my $f = shift;
-    require Data::Dumper;
-    warn "\n---------- [ ", $f->name, " ] ---------------\n";
-    warn "Field Type: ", ref($f),"\n";
-    warn "Required: ", ($f->required || '0'),"\n";
-    warn "Password: ", ($f->password || '0'),"\n";
-    my $v = $f->value;
-    warn "Value: ", Data::Dumper::Dumper $v;
-    my $iv = $f->init_value;
-    warn "InitValue: ", Data::Dumper::Dumper $iv;
-    my $i = $f->input;
-    warn "Input: ", Data::Dumper::Dumper $i;
-    if ( $f->can('options') ) {
-        my $o = $f->options;
-        warn "Options: ". Data::Dumper::Dumper $o;
-    }
-}
-
-
-
-
 =back
 
 =head1 AUTHOR
 
-Bill Moseley - with *much* help from John Siracusa.  Most of this
-is based on Rose-HTML-Form.  It's basically a very trimmed down version without
-all the HTML generation and the ability to do compound fields.
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-1;
-
