@@ -1,16 +1,19 @@
 package Form::Processor::Field::Boolean;
+{
+  $Form::Processor::Field::Boolean::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field';
-our $VERSION = '0.03';
 
-sub init_widget { 'radio' }  # although not really used.
+
+sub init_widget {return 'radio'}    # although not really used.
 
 
 sub value {
     my $self = shift;
 
-    my $v = $self->SUPER::value(@_);
+    my $v = $self->SUPER::value( @_ );
 
     return unless defined $v;
 
@@ -18,10 +21,24 @@ sub value {
 }
 
 
+# ABSTRACT: A true or false field
+
+
+1;
+
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::Boolean - A true or false field
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -43,24 +60,21 @@ This field's widget type is: "radio".
 Fields may inherit from other fields.  This field
 inherits from: "Field".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
-
-
