@@ -1,15 +1,18 @@
 package Form::Processor::Field::Checkbox;
+{
+  $Form::Processor::Field::Checkbox::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Boolean';
-our $VERSION = '0.03';
 
-sub init_widget { 'checkbox' }
+
+sub init_widget {return 'checkbox'}
 
 sub input_to_value {
     my $field = shift;
 
-    $field->value( $field->input ? 1 : 0 );
+    return $field->value( $field->input ? 1 : 0 );
 }
 
 sub value {
@@ -20,10 +23,24 @@ sub value {
 }
 
 
+# ABSTRACT: A boolean checkbox field type
+
+
+1;
+
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::Checkbox - A boolean checkbox field type
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -45,24 +62,21 @@ This field's widget type is: "checkbox".
 Fields may inherit from other fields.  This field
 inherits from: "Field".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
-
-
