@@ -1,9 +1,12 @@
 package Form::Processor::Field::FutureDate;
+{
+  $Form::Processor::Field::FutureDate::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::DateTime';
 use DateTime;
-our $VERSION = '0.03';
+
 
 
 my %date;
@@ -21,15 +24,29 @@ sub validate_value {
 
     return 1 if $field->value->clone->truncate( to => 'day' ) > DateTime->today;
 
-    return $field->add_error('This date must be in the future');
+    return $field->add_error( 'This date must be in the future' );
 
 }
 
 
+# ABSTRACT: DEPRECATED tests that the entered date is in the future
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::FutureDate - DEPRECATED tests that the entered date is in the future
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -51,25 +68,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "DateTime".
 
-
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-1;
-
