@@ -1,16 +1,33 @@
 package Form::Processor::Field::Hour;
+{
+  $Form::Processor::Field::Hour::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Minute';
-our $VERSION = '0.03';
 
 
-sub init_range_start { 0 }
-sub init_range_end { 23 }
+
+sub init_range_start {return 0}
+sub init_range_end   {return 23}
+
+# ABSTRACT: accept integer from 0 to 23
+
+
+
+
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
-Form::Processor::Field:: - accept integer from 0 to 23
+Form::Processor::Field::Hour - accept integer from 0 to 23
+
+=head1 VERSION
+
+version 1.122970
 
 =head1 SYNOPSIS
 
@@ -32,24 +49,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Minute".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
