@@ -1,11 +1,14 @@
 package Form::Processor::Field::Integer;
+{
+  $Form::Processor::Field::Integer::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
 
 
-sub init_size { 8 }
+
+sub init_size {10}
 
 sub validate {
     my $self = shift;
@@ -18,7 +21,7 @@ sub validate {
         $self->input( $value );
     }
 
-    return $self->add_error('Value must be an integer')
+    return $self->add_error( 'Value must be an integer' )
         unless $self->input =~ /^-?\d+$/;
 
     return 1;
@@ -27,20 +30,39 @@ sub validate {
 
 
 
+# ABSTRACT: validate an integer value
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::Integer - validate an integer value
+
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
 
 =head1 DESCRIPTION
 
-This accpets a positive or negative integer.  Negative integers may
+This accepts a positive or negative integer.  Negative integers may
 be prefixed with a dash.
 
-By default a max of eight digets are accepted.
+The intention of the Integer field is to be subclasses for specific uses.
 
+By default a max of ten digits are accepted.  This is a change form previous
+versions where it was limited to 8.  The change to 10 digits was to bring it in
+line with a common usage with 32 bit numbers.
 
 =head2 Widget
 
@@ -54,25 +76,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
-
