@@ -1,10 +1,13 @@
 package Form::Processor::Field::Money;
+{
+  $Form::Processor::Field::Money::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
 
-sub init_value_format { '%.2f' }
+
+sub init_value_format {'%.2f'}
 
 
 sub validate {
@@ -21,7 +24,7 @@ sub validate {
         $self->input( $value );
     }
 
-    return $self->add_error('Value must be a real number')
+    return $self->add_error( 'Value must be a real number' )
         unless $value =~ /^-?\d+\.?\d*$/;
 
 
@@ -32,10 +35,25 @@ sub validate {
 
 
 
+# ABSTRACT: Input US currenty-like values.
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::Money - Input US currenty-like values.
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -47,7 +65,6 @@ Formatted with two decimal places.
 
 Uses a period for the decimal point.  Not very locale smart, if you ask me.
 
-
 =head2 Widget
 
 Fields can be given a widget type that is used as a hint for
@@ -60,25 +77,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
-
