@@ -1,8 +1,11 @@
 package Form::Processor::Field::PosInteger;
+{
+  $Form::Processor::Field::PosInteger::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Integer';
-our $VERSION = '0.03';
+
 
 
 sub validate {
@@ -17,7 +20,7 @@ sub validate {
     }
 
 
-    return $self->add_error('Value must be a positive integer')
+    return $self->add_error( 'Value must be a positive integer' )
         unless $self->input >= 0;
 
     return 1;
@@ -25,10 +28,26 @@ sub validate {
 }
 
 
+# ABSTRACT: Validates input is a postive integer
+
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::PosInteger - Validates input is a postive integer
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -49,26 +68,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Integer".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-
-1;
-
