@@ -1,25 +1,40 @@
 package Form::Processor::Field::Readonly;
+{
+  $Form::Processor::Field::Readonly::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
-
-=item
-
-This field is a display only field
-
-=cut
-
-sub init_readonly { 1 };  # for html rendering
-
-sub init_noupdate { 1 }
 
 
 
+sub init_readonly { return 1};    # for html rendering
+
+sub init_noupdate { return 1}
+
+
+
+# ABSTRACT: Field that can be read but not updated
+
+
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::Readonly - Field that can be read but not updated
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -45,27 +60,25 @@ This field's widget type is: "text/readonly".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
+=item
 
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This field is a display only field
 
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-
-
-1;
-
