@@ -1,30 +1,105 @@
+# ABSTRACT: ** Please provide abstract **
+
 package Form::Processor::Field::Select;
+{
+  $Form::Processor::Field::Select::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field';
-our $VERSION = '0.03';
+
 
 
 use Rose::Object::MakeMethods::Generic (
     array => [
+
         # Array of hashes with value and label.
-        options         => { interface=> 'get_set_init' },
-        reset_options   => { interface => 'reset', hash_key => 'options' },
+        options => { interface => 'get_set_init' },
+        reset_options => { interface => 'reset', hash_key => 'options' },
     ],
     scalar => [
-        multiple        => { interface => 'get_set_init' },
-        size            => { interface => 'get_set_init' },
+        multiple => { interface => 'get_set_init' },
+        size     => { interface => 'get_set_init' },
 
-        label_column    => { interface => 'get_set_init' },
-        active_column   => { interface => 'get_set_init' },
-        auto_widget_size=> { interface => 'get_set_init' },
-        sort_order      => {},
+        label_column     => { interface => 'get_set_init' },
+        active_column    => { interface => 'get_set_init' },
+        auto_widget_size => { interface => 'get_set_init' },
+        sort_order       => {},
     ],
 );
 
+
+sub init_options { [] }
+
+sub init_widget {'select'}
+
+
+sub init_multiple {0}
+
+
+sub init_auto_widget_size {0}
+
+
+sub select_widget {
+    my $field = shift;
+
+    my $size = $field->auto_widget_size;
+
+    return $field->widget unless $field->widget eq 'select' && $size;
+
+    my $options = $field->options || [];
+
+    return 'select' if @$options > $size;
+
+    return $field->multiple ? 'checkbox' : 'radio';
+}
+
+
+
+
+sub init_size {0}
+
+
+
+sub init_label_column {'name'}
+
+
+
+sub init_active_column {'active'}
+
+
+
+
+
+
+
+sub as_label {
+    my $field = shift;
+
+    my $value = $field->value;
+    return unless defined $value;
+
+    for ( $field->options ) {
+        return $_->{label} if $_->{value} eq $value;
+    }
+
+    return;
+}
+
+
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Form::Processor::Field::Select
+Form::Processor::Field::Select - ** Please provide abstract **
+
+=head1 VERSION
+
+version 1.122970
 
 =head1 SYNOPSIS
 
@@ -47,28 +122,21 @@ This field's widget type is: "select".
 Fields may inherit from other fields.  This field
 inherits from: "Field"
 
-=head1 METHODS
+=head1 NAME
 
+Form::Processor::Field::Select
+
+=head1 METHODS
 
 =head2 options
 
 This is an array of hashes for this field.
 Each has must have a label and value keys.
 
-=cut
-
-sub init_options { [] };
-
-sub init_widget { 'select' }
-
 =head2 multiple
 
 If true allows multiple input values
 
-=cut
-
-sub init_multiple { 0 }
-
 =head2 auto_widget_size
 
 This is a way to provide a hint as to when to automatically
@@ -78,10 +146,6 @@ select lists smaller than the size specified.
 
 See L<select_widget> below.
 
-=cut
-
-sub init_auto_widget_size { 0 }
-
 =head2 select_widget
 
 If the widget is 'select' for the field then will look if the field
@@ -89,24 +153,6 @@ also has a L<auto_widget_size>.  If the options list is less than or equal
 to the L<auto_widget_size> then will return C<radio> if L<multiple> is false,
 otherwise will return C<checkbox>.
 
-=cut
-
-sub select_widget {
-    my $field = shift;
-
-    my $size = $field->auto_widget_size;
-
-    return $field->widget unless $field->widget eq 'select' && $size;
-
-    my $options = $field->options || [];
-
-    return 'select' if @$options > $size;
-
-    return $field->multiple ? 'checkbox' : 'radio';
-}
-
-
-
 =head2 size
 
 This can be used to store how many items should be offered in the UI
@@ -114,11 +160,6 @@ at a given time.
 
 Defaults to 0.
 
-=cut
-
-sub init_size { 0 }
-
-
 =head2 label_column
 
 Sets or returns the name of the method to call on the foreign class
@@ -129,11 +170,6 @@ object class for the label for select lists.
 
 Defaults to "name"
 
-=cut
-
-sub init_label_column { 'name' }
-
-
 =head2 active_column
 
 Sets or returns the name of a boolean column that is used as a flag to indicate that
@@ -148,11 +184,6 @@ The exception is any columns that are marked inactive, but are also part of the
 input data will be included with brackets around the label.  This allows
 updating records that might have data that is now considered inactive.
 
-=cut
-
-sub init_active_column { 'active' }
-
-
 =head2 sort_order
 
 Sets or returns the column used in the foreign class for sorting the
@@ -164,11 +195,6 @@ by this column.
 If not defined or the column is not found as a method on the foreign class then
 the label_column is used as the sort condition.
 
-=cut
-
-
-
-
 =head2 as_label
 
 Returns the option label for the option value that matches the field's current value.
@@ -176,38 +202,21 @@ Can be helpful for displaying information about the field in a more friendly for
 
 This does a string compare, although probably al
 
-=cut
-
-sub as_label {
-    my $field = shift;
-
-    my $value = $field->value;
-    return unless defined $value;
-
-    for ( $field->options ) {
-        return $_->{label} if $_->{value} eq $value;
-    }
-
-    return;
-}
-
-
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
