@@ -1,8 +1,11 @@
 package Form::Processor::Field::URL;
+{
+  $Form::Processor::Field::URL::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
+
 
 
 sub validate {
@@ -12,8 +15,8 @@ sub validate {
 
     my $url = $self->input;
 
-    return $self->add_error('Enter a plain url "e.g. http://google.com/"')
-        unless $url =~ m{^\w+://[^/\s]+/\S*$}; 
+    return $self->add_error( 'Enter a plain url "e.g. http://google.com/"' )
+        unless $url =~ m{^\w+://[^/\s]+/\S*$};
 
     return 1;
 
@@ -21,10 +24,26 @@ sub validate {
 }
 
 
+# ABSTRACT: Tests that a url looks like a url.
+
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::URL - Tests that a url looks like a url.
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -49,26 +68,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-
-1;
-
