@@ -1,8 +1,11 @@
 package Form::Processor::Field::USPhone;
+{
+  $Form::Processor::Field::USPhone::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
+
 
 sub validate {
     my $self = shift;
@@ -13,17 +16,34 @@ sub validate {
 
     $input =~ s/\D//g;
 
-    return $self->add_error('Phone Number must be 10 digits, including area code')
+    return $self->add_error( 'Phone Number must be 10 digits, including area code' )
         unless length $input == 10;
 
     return 1;
 }
 
 
+# ABSTRACT: Validate that the input looks like a US phone number
+
+
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::USPhone - Validate that the input looks like a US phone number
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -47,27 +67,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-
-
-1;
-
