@@ -1,26 +1,44 @@
 package Form::Processor::Field::USZipcode;
+{
+  $Form::Processor::Field::USZipcode::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
 
 
-sub validate { 
+
+sub validate {
     my $self = shift;
 
     return unless $self->SUPER::validate;
 
-    return $self->add_error('US Zip code must be 5 or 9 digits')
+    return $self->add_error( 'US Zip code must be 5 or 9 digits' )
         unless $self->input =~ /^(\s*\d{5}(?:[-]\d{4})?\s*)$/;
 
     return 1;
 }
 
 
+# ABSTRACT: Checks that input looks like a US Zip.
+
+
+
+
+1;
+
+
+__END__
+=pod
+
 =head1 NAME
 
 Form::Processor::Field::USZipcode - Checks that input looks like a US Zip.
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -41,25 +59,21 @@ This field's widget type is: "text".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
-
