@@ -1,16 +1,34 @@
 package Form::Processor::Field::Upload;
+{
+  $Form::Processor::Field::Upload::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
-our $VERSION = '0.03';
 
-sub init_widget { 'file' }
 
+sub init_widget {return 'file'}
+
+
+# ABSTRACT: A field for uploading files
+
+
+
+
+1;
+
+
+__END__
+=pod
 
 =head1 NAME
 
 Form::Processor::Field::Upload - A field for uploading files
 
+=head1 VERSION
+
+version 1.122970
+
 =head1 SYNOPSIS
 
 See L<Form::Processor>
@@ -31,25 +49,21 @@ This field's widget type is: "file".
 Fields may inherit from other fields.  This field
 inherits from: "Text".
 
-=head1 AUTHORS
-
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
-
