@@ -1,8 +1,13 @@
+# ABSTRACT: ** Please provide abstract **
+
 package Form::Processor::Field::WeekdayStr;
+{
+  $Form::Processor::Field::WeekdayStr::VERSION = '1.122970';
+}
 use strict;
 use warnings;
 use base 'Form::Processor::Field::Weekday';
-our $VERSION = '0.03';
+
 
 
 # Join the list of values into a single string
@@ -25,9 +30,26 @@ sub format_value {
 }
 
 
+
+
+
+1;
+
+
+
+
+
+
+__END__
+=pod
+
 =head1 NAME
 
-Form::Processor::Field::WeekdayStr
+Form::Processor::Field::WeekdayStr - ** Please provide abstract **
+
+=head1 VERSION
+
+version 1.122970
 
 =head1 SYNOPSIS
 
@@ -38,7 +60,6 @@ See L<Form::Processor>
 This allow storage of multiple days of the week in a single string field.
 as digits.
 
-
 =head2 Widget
 
 Fields can be given a widget type that is used as a hint for
@@ -51,29 +72,25 @@ This field's widget type is: "select".
 Fields may inherit from other fields.  This field
 inherits from: "Weekday".
 
-=head1 AUTHORS
+=head1 NAME
 
-Bill Moseley
-
-=head1 COPYRIGHT
-
-See L<Form::Processor> for copyright.
-
-This library is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
+Form::Processor::Field::WeekdayStr
 
 =head1 SUPPORT / WARRANTY
 
 L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
 Users are expected to review software for fitness and usability.
 
+=head1 AUTHOR
+
+Bill Moseley <mods@hank.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Bill Moseley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
-
-1;
-
-
-
-
-
